==> mzanalytics_mybmw-0.1.3.tar.gz: lib/mzanalytics_android.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class Mzanalytics_android {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> initEvent() async {
    try {
      _channel.invokeMethod('initEvent');
    } on PlatformException {}
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);

    } on PlatformException {}
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException {}
  }

  static Future<String> getOaid() async {
    try {
      return _channel.invokeMethod('getOaid');
    } on PlatformException {}
    return "";
  }

  static Future<String> getCid() async {
    try {
      return _channel.invokeMethod('getCid');
    } on PlatformException {}
    return "";
  }

  static Future<String> setCd(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException {}
    return "";
  }

  static Future<String> setCm(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException {}
    return "";
  }

  static Future<String> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException {}
    return "";
  }

  static Future<String> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException {}
    return "";
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException {}
    return Map();
    
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException {}
    return false;
  }

  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException {}
    return List();
  }



 

 

  

  
}

==> mzanalytics_mybmw-0.1.4.tar.gz: lib/mzanalytics_android.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class Mzanalytics_android {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> initEvent() async {
    try {
      _channel.invokeMethod('initEvent');
    } on PlatformException {}
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);

    } on PlatformException {}
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException {}
  }

  static Future<String> getOaid() async {
    try {
      return _channel.invokeMethod('getOaid');
    } on PlatformException {}
    return "";
  }

  static Future<String> getCid() async {
    try {
      return _channel.invokeMethod('getCid');
    } on PlatformException {}
    return "";
  }

  static Future<void> setCd(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException {}
   
  }

  static Future<void> setCm(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException {}
   
  }

  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException {}
  }

  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException {}
  
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException {}
    return Map();
    
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException {}
    return false;
  }

  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException {}
    return [];
  }



 

 

  

  
}
